(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    122523,       2516]
NotebookOptionsPosition[    112533,       2376]
NotebookOutlinePosition[    113171,       2400]
CellTagsIndexPosition[    113128,       2397]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 7, Section 7.3", "Section",ExpressionUUID->"68e7a372-2af0-423f-a89d-9014c82b299a"],

Cell[TextData[{
 "We start by defining a function ",
 StyleBox["secular", "Input"],
 " that derives a secular perturbation theory for any number of masses with \
given orbital elements."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9719ce43-3705-43bc-b327-9ad9c849b491"],

Cell["\<\
(* 
               ==== Secular perturbation solver ==== 
                       v1.0 February 1993 
                         Carl D. Murray             
*)


secular::usage = \"secular[nbody, m, a, ecc, inc, peri, node, n,
\trp, j2, j4] determines the secular perturbation solution for
\tthe gravitational interaction of nbody bodies with mass ratios
\tm, semi-major axes, a, eccentricities, ecc, inclinations, inc,
\tlongitudes of pericentre, peri, longitudes of ascending node,
\tnode, mean motions, n (in degrees/year) which are orbiting a
\tcentral body of radius, rp with J2 and J4 values, j2 and j4.
\tThe function defines ecalc and icalc which can be used to plot
\tthe time variation of the eccentricity and inclination of
\tany of the bodies.\";

secular[nbody_, m_, a_, ecc_, inc_, peri_, node_, n_, 
        rp_, j2_, j4_] :=
(* 
   Based on the theory given in Dermott & Nicholson, Nature,
   319, 115-120.
   
   nbody : number of bodies
   m     : masses of bodies
   a     : semi-major axes of bodies
   ecc   : eccentricities of bodies
   inc   : inclinations of bodies
   peri  : longitudes of pericentre of bodies
   node  : longitudes of ascending nodes of bodies
   n     : mean motion (in degrees/year) of bodies
   rp    : radius of central object
   j2    : J2 of central object
   j4    : J4 of central object
*)  
Module[{rpa2 = N[(rp/a)^2], rpa4 = N[(rp/a)^4], j22=j2*j2,
        mred = 1+m},
Print[\"Mass ratios :\"];
Print[m];
Print[\" \"];
Print[\"Semi-major axes :\"];
Print[a];
Print[\" \"];
Print[\"Mean motions (degrees/year) :\"];
Print[n];
Print[\" \"];
Print[\"Initial values :\"];
Print[\"==============  \"];
Print[\" \"];
Print[\"Eccentricities :\"];
Print[ecc];
Print[\" \"];
Print[\"Longitudes of pericentre :\"];
Print[peri];
Print[\" \"];
Print[\"Inclinations :\"];
Print[inc];
Print[\" \"];
Print[\"Longitudes of ascending node :\"];
Print[node];
Print[\" \"];
(* 
   Set the initial values of h, k, p, q
*)
hinit = ecc*Sin[N[peri]];
kinit = ecc*Cos[N[peri]];
pinit = N[inc*Sin[node]];
qinit = N[inc*Cos[node]];
(*
   Define the alpha, alphabar functions from the D&N paper
*)
alpha[ j_, k_ ] := a[[k]]/a[[j]] /; k <  j;
alpha[ j_, k_ ] := 0             /; k == j;
alpha[ j_, k_ ] := a[[j]]/a[[k]] /; k >  j;
alphabar[ j_, k_ ] := 1             /; k <  j;
alphabar[ j_, k_ ] := 0             /; k == j;
alphabar[ j_, k_ ] := alpha[ j, k ] /; k >  j;
(*
  Define the Laplace coefficient function using a numerical
  integration
*)
laplace[ s_, jj_, aa_ ] := 
  If[aa != 0,
     NIntegrate[ N[ (1/Pi)*(Cos[jj*x])/((1-2aa*Cos[x]+aa^2)^s) ],
                {x, 0, 2Pi} ],
     0];
(*
  Define the elements of the matrices A and B
*)
A[ j_, k_ ] := -(1/4)*m[[k]]*(n[[j]]/mred[[j]])*
                 alpha[j,k]*alphabar[j,k]*
                 laplace[3/2, 2, alpha[j,k]] /; j != k;
A[ j_, k_ ] := n[[j]]*
               ((3/2)*j2*rpa2[[j]] - (9/8)*j22*rpa4[[j]] -
                (15/4)*j4*rpa4[[j]] +
                ((1/4)/mred[[j]])*
                         Sum[If[l != j,
                            m[[l]]*
                            alpha[j,l]*alphabar[j,l]*
                            laplace[3/2, 1, alpha[j,l]],
                            0],
                          {l,nbody}]) /; j == k;
B[ j_, k_ ] := (1/4)*m[[k]]*(n[[j]]/mred[[j]])*
                 alpha[j,k]*alphabar[j,k]*
                 laplace[3/2, 1, alpha[j,k]] /; j != k;
B[ j_, k_ ] := -n[[j]]*
               ((3/2)*j2*rpa2[[j]] - (27/8)*j22*rpa4[[j]] -
                (15/4)*j4*rpa4[[j]] +
                ((1/4)/mred[[j]])*
                         Sum[If[l != j,
                            m[[l]]*
                            alpha[j,l]*alphabar[j,l]*
                            laplace[3/2,1,alpha[j,l]],
                            0],
                          {l,nbody}]) /; j == k;
(*
  Construct the two matrices
*)
bigA = Array[ A, {nbody,nbody} ];
bigB = Array[ B, {nbody,nbody} ];
Print[\"Matrix A (deg/yr):\"];
Print[MatrixForm[bigA]];
Print[\" \"];
Print[\"Matrix B (deg/yr):\"];
Print[MatrixForm[bigB]];
Print[\" \"];
(*
  Solve the resulting eigensystems
*)
esA = Eigensystem[ bigA ];
esB = Eigensystem[ bigB ];
(*
  Extract the two sets of eigenfrequencies ...
*)
g = esA[[1]];
f = esB[[1]];
Print[\"g eigenfrequencies (deg/yr) :\"];
Print[g];
Print[\" \"];
Print[\"g eigenvectors :\"];
Print[MatrixForm[esA[[2]]]];
Print[\" \"];
Print[\"f eigenfrequencies (deg/yr) :\"];
Print[f];
Print[\" \"];
Print[\"f eigenvectors :\"];
Print[MatrixForm[esB[[2]]]];
Print[\" \"];
Print[\"Initial h values :\"];
Print[hinit];
Print[\" \"];
Print[\"Initial k values :\"];
Print[kinit];
Print[\" \"];
Print[\"Initial p values :\"];
Print[pinit];
Print[\" \"];
Print[\"Initial q values :\"];
Print[qinit];
Print[\" \"];
(*
  ... and the corresponding (unscaled) eigenvectors
*)
ebarji = Transpose[esA[[2]]];
ibarji = Transpose[esB[[2]]];
(*
  Determine the values of Sin[beta] and Sin[gamma] and hence
  the scaling of the eigenvectors
*)
fsbeta = LinearSolve[ebarji, hinit];
fcbeta = LinearSolve[ebarji, kinit];
beta = ArcTan[fcbeta, fsbeta];
Print[\"Beta (deg) :\"];
Print[N[beta/Degree]];
Print[\" \"];
sbeta = Sin[beta];
fsgamma = LinearSolve[ibarji, pinit];
fcgamma = LinearSolve[ibarji, qinit];
gamma = ArcTan[fcgamma, fsgamma];
Print[\"Gamma (deg) :\"];
Print[N[gamma/Degree]];
Print[\" \"];
sgamma = Sin[gamma];
emag = fsbeta/sbeta;
imag = fsgamma/sgamma;
eji = Map[Times[#,emag]&, ebarji];
iji = Map[Times[#,imag]&, ibarji];
gr = N[g Degree];
fr = N[f Degree];
Print[\"Scaled h-k eigenvectors :\"];
Print[MatrixForm[eji]];
Print[\" \"];
Print[\"Scaled p-q eigenvectors :\"];
Print[MatrixForm[iji]];
Print[\" \"];
(*
  Use these values to determine e and I as functions of time
*)
ejcalc[j_, t_] := 
  Sqrt[(Plus @@ (eji[[j]]*Sin[gr*t+beta]))^2 + 
       (Plus @@ (eji[[j]]*Cos[gr*t+beta]))^2];
ijcalc[j_, t_] := 
  N[
   Sqrt[(Plus @@ (iji[[j]]*Sin[fr*t+gamma]))^2 + 
        (Plus @@ (iji[[j]]*Cos[fr*t+gamma]))^2]]
];\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[1]:=",ExpressionUUID->"ff4590b1-a226-44e0-963f-eb797962fbce"],

Cell[TextData[{
 "Now apply the function ",
 StyleBox["secular", "Input"],
 " to the Jupiter-Saturn system.  Note that we are using mean motions derived \
from Kepler's third law and we are setting J2 and J4 to be zero (i.e. there \
is no oblateness of the central body to consider)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e62469f6-7147-47e0-a9d0-edeb822093c2"],

Cell[CellGroupData[{

Cell["\<\
secular[2, 
        {1./(1047.355), 1./(3498.500)},
        {5.202545297, 9.554840607},
        {0.047462192, 0.057548133},
        {1.30667, 2.48795} Degree,
        {13.983865305, 88.719424868} Degree,
        {100.0381, 113.1334} Degree,
        {360./5.202545297^(3/2), 360./9.554840607^(3/2)},
        0,
        0,
        0];
\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[7]:=",ExpressionUUID->"857dc722-28aa-4132-99b2-fcba09c84fd1"],

Cell[BoxData["\<\"Mass ratios :\"\>"], "Print",
 CellChangeTimes->{3.81139653331144*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"568da61b-af5c-4d27-b874-f4a8c4bc46ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.0009547861040430418`", ",", "0.0002858367871945119`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.811396533312139*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"baee26f3-dd13-4f5d-ac4a-fad1db128c00"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653331257*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"fe515c50-d2b4-4474-93e8-f1019f80d3cc"],

Cell[BoxData["\<\"Semi-major axes :\"\>"], "Print",
 CellChangeTimes->{3.8113965333129683`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"544eb284-4810-4744-93d1-68b00095e906"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.202545297`", ",", "9.554840607`"}], "}"}]], "Print",
 CellChangeTimes->{3.811396533313415*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"d4f2f228-d017-417f-bf48-a82d531fd84b"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.8113965333138227`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"317530b1-878e-4bd1-b3b4-f47fcb3aa7e6"],

Cell[BoxData["\<\"Mean motions (degrees/year) :\"\>"], "Print",
 CellChangeTimes->{3.811396533314227*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"a1eabd2a-01da-4a0c-8baa-7ece57a6ab46"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"30.337423590928935`", ",", "12.18897905804579`"}], "}"}]], "Print",\

 CellChangeTimes->{3.811396533314661*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"2a998053-083c-4189-8906-18630a832f16"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533315065*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"84812f71-806f-4f54-9522-c3eb0a38e55d"],

Cell[BoxData["\<\"Initial values :\"\>"], "Print",
 CellChangeTimes->{3.811396533315474*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"07464b55-bc3d-49e5-8dbf-f2485138f2f3"],

Cell[BoxData["\<\"==============  \"\>"], "Print",
 CellChangeTimes->{3.811396533315878*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"a3ee8972-9301-4f4d-b502-9c28f5bc34fd"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533316279*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"3bbc281f-1089-46ef-bed1-97f23b025f62"],

Cell[BoxData["\<\"Eccentricities :\"\>"], "Print",
 CellChangeTimes->{3.8113965333166647`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"47bbcd92-5378-47ce-9f4c-b531cca42bcb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.047462192`", ",", "0.057548133`"}], "}"}]], "Print",
 CellChangeTimes->{3.811396533317086*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"6268d31a-c76a-4663-9435-83fc7084930e"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533317493*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"5f6f535e-bc60-40a8-b154-fc150d6a0e64"],

Cell[BoxData["\<\"Longitudes of pericentre :\"\>"], "Print",
 CellChangeTimes->{3.811396533317891*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"434cb6bf-d670-4762-a278-09e3d9c82f2a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.24406449172765107`", ",", "1.5484460744223356`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.811396533318314*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"ffa19731-a99f-4d8d-872a-812b97ee792f"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533318715*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"12b7fb57-0881-4a47-8e95-0076f6bdd9b3"],

Cell[BoxData["\<\"Inclinations :\"\>"], "Print",
 CellChangeTimes->{3.8113965333190937`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"7ef11fac-717f-473d-88f8-d9924e92bfed"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.022805693737034307`", ",", "0.04342291912499292`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8113965333194923`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"3282959c-9db7-4888-bc74-f57e44e786f2"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533319934*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"d0ee8afc-0f42-42c9-ae76-8ba2bb32cd15"],

Cell[BoxData["\<\"Longitudes of ascending node :\"\>"], "Print",
 CellChangeTimes->{3.811396533320345*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"790075c7-6185-44c7-bdbc-8ce77a80abcc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.7459942224393394`", ",", "1.9745503239757527`"}], "}"}]], "Print",\

 CellChangeTimes->{3.811396533320825*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"1199f9e5-75cb-4a56-85af-9a89bf5baf0e"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533321241*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"dd7bde0b-d06b-4519-adcd-86bc4102cee9"],

Cell[BoxData["\<\"Matrix A (deg/yr):\"\>"], "Print",
 CellChangeTimes->{3.811396533356888*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"f976ed5b-922d-4c8f-be2a-870b9ab17c1f"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.002037382384210047`", 
      RowBox[{"-", "0.0013298659060103283`"}]},
     {
      RowBox[{"-", "0.003280064415541723`"}], "0.005025127292230189`"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.811396533403143*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"67a26301-b166-44b4-9d1f-182ff7398e70"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533404142*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"679ecc8f-4916-4433-b6a7-a9b14d94f272"],

Cell[BoxData["\<\"Matrix B (deg/yr):\"\>"], "Print",
 CellChangeTimes->{3.8113965334046097`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"9d0f1f3b-71ba-49e3-839b-e4fef2dc8707"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.002037382384210047`"}], "0.002037382384210047`"},
     {"0.00502512729223019`", 
      RowBox[{"-", "0.005025127292230189`"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.811396533405201*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"bc8825b5-94f6-42ae-b828-335fe4d15d82"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533405754*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"dc2b674a-62d4-4abe-a15a-a4dcedb6dfce"],

Cell[BoxData["\<\"g eigenfrequencies (deg/yr) :\"\>"], "Print",
 CellChangeTimes->{3.811396533406197*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"f066d13a-c05d-45af-b8f4-b23a38a19a97"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.006099075070361905`", ",", "0.0009634346060783307`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.811396533406649*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"b6dfbf21-5f78-4086-9925-792c393bcaa7"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533407076*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"c71bc94f-cf4c-4fc8-94e9-f28e3b287c1f"],

Cell[BoxData["\<\"g eigenvectors :\"\>"], "Print",
 CellChangeTimes->{3.811396533407495*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"2d01e95e-24e9-467e-81f4-d1dec786c79c"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.3111626228257313`", 
      RowBox[{"-", "0.9503566815444672`"}]},
     {
      RowBox[{"-", "0.7779911306128082`"}], 
      RowBox[{"-", "0.62827525869463`"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.8113965334080467`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"74ea6bd1-9b46-4f00-927a-361b725474d8"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533408568*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"9f9b9f6f-cccf-4d8e-940e-f6314c1d5fac"],

Cell[BoxData["\<\"f eigenfrequencies (deg/yr) :\"\>"], "Print",
 CellChangeTimes->{3.811396533408988*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"bf660131-47ea-4cd1-9f40-4ade024983b6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.007062509676440236`"}], ",", "0.`"}], "}"}]], "Print",
 CellChangeTimes->{3.8113965334094343`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"a1ae6da8-7fca-4137-b83b-2db8bc0cf5e1"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533409886*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"3a6dc0ca-1c24-4bef-a994-0034b4ad8bf1"],

Cell[BoxData["\<\"f eigenvectors :\"\>"], "Print",
 CellChangeTimes->{3.811396533410321*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"9d7ed026-846d-4b68-ae34-85a6e396c277"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.37573181540105655`"}], "0.9267284407502699`"},
     {"0.7071067811865475`", "0.7071067811865476`"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.8113965334108686`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"79f31eb9-38da-4a74-a2f0-c39ac4286b09"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.8113965334114323`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"3156fbb5-8c6e-487d-8502-0a567d11a0c0"],

Cell[BoxData["\<\"Initial h values :\"\>"], "Print",
 CellChangeTimes->{3.8113965334118223`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"99adcd7c-1b01-410c-8371-c4af8c6091ff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.011469174494143752`", ",", "0.057533759980095495`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.811396533412239*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"ccf5c3b1-3643-4bd0-89ac-72064cf1a204"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533412641*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"09dfaa42-37de-49a4-9691-b8ac4bf2d694"],

Cell[BoxData["\<\"Initial k values :\"\>"], "Print",
 CellChangeTimes->{3.8113965334130373`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"8e855058-f3de-49f2-b644-5b0ab3e3ba91"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.04605559364363623`", ",", "0.0012861082141292612`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.811396533413452*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"10df05de-7d31-4124-acd9-c0732ac80b98"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533413851*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"5947a0ae-8fb7-4af5-8bf5-79dfdc838f5e"],

Cell[BoxData["\<\"Initial p values :\"\>"], "Print",
 CellChangeTimes->{3.811396533414239*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"b4ae0fd4-2425-4c5b-bfee-891eb9dbb54e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.022456585645556557`", ",", "0.03993139648993428`"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.8113965334146547`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"84067e1c-3337-4cf3-903f-7a191132aa1e"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533415057*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"9783fb08-1e51-4b3d-ba25-e98e9bfcd72a"],

Cell[BoxData["\<\"Initial q values :\"\>"], "Print",
 CellChangeTimes->{3.8113965334154673`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"303d07fc-411e-4630-8a9f-e7c3c0ff4572"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.0039751010013821`"}], ",", 
   RowBox[{"-", "0.0170597033883752`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.811396533415915*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"eeb25984-06f2-4d1c-90eb-e8b55e622aa6"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533416335*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"d8666d8e-d259-415e-b6c8-30c856b36038"],

Cell[BoxData["\<\"Beta (deg) :\"\>"], "Print",
 CellChangeTimes->{3.811396533416752*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"9c0a36ff-5319-40d3-b321-2c1dab625698"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "53.35652579154743`"}], ",", 
   RowBox[{"-", "146.89228735922418`"}]}], "}"}]], "Print",
 CellChangeTimes->{3.811396533417192*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"df60c24c-dba1-4db1-87bf-381f0efe161d"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.811396533417597*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"0b2066aa-3a5c-43df-8b4a-6544f2bac26b"],

Cell[BoxData["\<\"Gamma (deg) :\"\>"], "Print",
 CellChangeTimes->{3.811396533418003*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"d6437445-a7f3-468c-a4b4-6e53d917d18d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"126.82474313164487`", ",", "105.73953087222233`"}], "}"}]], "Print",\

 CellChangeTimes->{3.811396533418427*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"a3788416-04e6-4a2e-87f1-39c3298ed339"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.81139653341883*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"d0ded35a-1fe8-4ccf-9bb9-d6b856990e04"],

Cell[BoxData["\<\"Scaled h-k eigenvectors :\"\>"], "Print",
 CellChangeTimes->{3.8113965334192257`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"f266d361-e4da-4471-8719-3efb465d7920"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.015578798592281971`", 
      RowBox[{"-", "0.04388211060645147`"}]},
     {
      RowBox[{"-", "0.047580956858377495`"}], 
      RowBox[{"-", "0.035437479051487746`"}]}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.8113965334197807`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"a9ef78f6-7b6a-4ab4-8a8f-de68b7e5596b"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.8113965334203176`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"2a024105-fdd6-43ac-b891-f2801f536d70"],

Cell[BoxData["\<\"Scaled p-q eigenvectors :\"\>"], "Print",
 CellChangeTimes->{3.81139653342072*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"5ca39519-337b-4481-b576-7a7244aa877f"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "0.006297664190201552`"}], "0.028568889014972485`"},
     {"0.01553295269692481`", "0.02856888901497249`"}
    },
    GridBoxAlignment->{"Columns" -> {{Center}}, "Rows" -> {{Baseline}}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.811396533421253*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"49cdcf96-5c39-4f7f-ab0d-8778e47cf390"],

Cell[BoxData["\<\" \"\>"], "Print",
 CellChangeTimes->{3.8113965334217997`*^9},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"f3a8bdb3-213c-4347-87ff-9e15c3754ea5"]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["secular", "Input"],
 " has also defined a function ",
 StyleBox["ejcalc", "Input"],
 " that returns the eccentricity of any of the bodies at a specific time. We \
can use this to derive Eq.(7.52)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"710d2172-b75e-4f02-bd8e-aa87cd85d443"],

Cell[CellGroupData[{

Cell["Chop[FullSimplify[ejcalc[1,t]]]", "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"ccba448d-6c91-443c-94cc-42c522113d36"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"0.002168338596855727`", "\[VeryThinSpace]", "-", 
   RowBox[{"0.0013672611258842959`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"1.6325070077163324`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.00008963383530039862`", " ", "t"}]}], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.8113965334704514`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"479d14d3-1464-4d7e-8456-1dd397dbee44"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Chop[FullSimplify[ejcalc[2,t]]]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[10]:=",ExpressionUUID->"4c549b27-c282-4bbc-8495-e53f03b7025a"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"0.003519762377083413`", "\[VeryThinSpace]", "+", 
   RowBox[{"0.0033722983238369895`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"1.6325070077163324`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.00008963383530039862`", " ", "t"}]}], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.811396533519546*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"7f6adad4-3c3d-4044-bba1-f69808e81752"]
}, Open  ]],

Cell["Convert some of the constants for a proper comparison.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1e9a84a8-55da-4a7a-ae62-dbe7a5b67297"],

Cell[CellGroupData[{

Cell["N[0.0000896338/Degree]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[11]:=",ExpressionUUID->"11ff5ff5-828d-4a60-8f2a-279fb77096cf"],

Cell[BoxData["0.005135638441719719`"], "Output",
 CellChangeTimes->{3.811396533523951*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"84f078e9-d771-47a5-8c25-f5fd6c3c0371"]
}, Open  ]],

Cell[CellGroupData[{

Cell["N[1.63251/Degree]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[12]:=",ExpressionUUID->"5bd21521-0d3b-44fa-8392-cc38b4d4456d"],

Cell[BoxData["93.53593301290202`"], "Output",
 CellChangeTimes->{3.811396533571162*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"326ebcd8-98c0-4a85-973e-191442fd80b9"]
}, Open  ]],

Cell[TextData[{
 "The function ",
 StyleBox["secular", "Input"],
 " has also defined a function ",
 StyleBox["ijcalc", "Input"],
 " that returns the inclination of any of the bodies at a specific time. We \
can use this to derive Eq.(7.53)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4144d348-7f5a-42a9-90f5-b2fb4a4b38ee"],

Cell[CellGroupData[{

Cell["Chop[FullSimplify[ijcalc[1,t]]]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[13]:=",ExpressionUUID->"7be96441-07da-46ae-8c48-d1b95c822372"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"0.0008558419938023625`", "\[VeryThinSpace]", "-", 
   RowBox[{"0.00033574232697495675`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"0.00012326404730784153`", " ", "t"}], "]"}]}], "-", 
   RowBox[{"0.000129452636326418`", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"0.00012326404730784153`", " ", "t"}], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.811396533620422*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"50d7e277-2ef9-4120-a791-95c7c6ac2f02"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Chop[FullSimplify[ijcalc[2,t]]]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[14]:=",ExpressionUUID->"915be487-a204-4026-beea-cf2795772640"],

Cell[BoxData[
 SqrtBox[
  RowBox[{"0.0010574540390347192`", "\[VeryThinSpace]", "+", 
   RowBox[{"0.0008280958663009566`", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"0.00012326404730784153`", " ", "t"}], "]"}]}], "+", 
   RowBox[{"0.0003192900757838133`", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"0.00012326404730784153`", " ", "t"}], "]"}]}]}]]], "Output",
 CellChangeTimes->{3.811396533669244*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"02c01e5d-1e8f-419b-921a-0d0b6c71c825"]
}, Open  ]],

Cell["Convert some of the constants for a proper comparison.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fd03c01e-928d-4843-aa00-23d5b178a19e"],

Cell[CellGroupData[{

Cell["N[0.368006/Degree]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[15]:=",ExpressionUUID->"a35aed60-87fc-4c3a-a3df-fa3cbbe54ffd"],

Cell[BoxData["21.085190635491372`"], "Output",
 CellChangeTimes->{3.811396533673615*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"a156b4d9-9876-4f60-996b-259e110d00b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["N[0.000123264/Degree]", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[16]:=",ExpressionUUID->"bfb5f243-9d30-4205-ae02-20b7bf1c1a1d"],

Cell[BoxData["0.007062506965900579`"], "Output",
 CellChangeTimes->{3.8113965337232*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"7805fd59-02e5-4d02-ba7a-de6250b11bc7"]
}, Open  ]],

Cell["\<\
Now plot the evolution of the eccentricities of Jupiter and Saturn as a \
function of time (see Fig.7.1a).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"30238e04-ba0e-4c82-9b9f-17345e4ea5be"],

Cell[CellGroupData[{

Cell["\<\
Plot[{ejcalc[1,t],ejcalc[2,t]},{t,-100000,100000},
      PlotRange->{{-100000,100000},{0,0.1}},Frame->True]\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[17]:=",ExpressionUUID->"01efd926-c74f-4fa0-b413-1b51f76b30dd"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwtm3k8lN8Xx20haZFQaFGSkpTQJucmtGkXKpWI7JJIUhEhlUoqlWesEWYe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       "]]},
     Annotation[#, "Charting`Private`Tag$1805#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwtm3k41N8XxyVbJRLSLiWJJIV255KkaBNSJFsKhVS2VIpkkH0rUfYl+8yk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       "]]},
     Annotation[#, "Charting`Private`Tag$1805#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-100000, 100000}, {0, 0.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811396533929185*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"22e93b82-c551-41d7-8a74-f1982c99ee59"]
}, Open  ]],

Cell["\<\
Do the same for the inclinations of Jupiter and Saturn (see Fig.7.1b).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1bbe19d2-36b5-4d98-9fd6-024baa06792f"],

Cell[CellGroupData[{

Cell["\<\
Plot[{ijcalc[1,t]/Degree,ijcalc[2,t]/Degree},{t,-100000,100000},
      PlotRange->{{-100000,100000},{0,3}},Frame->True]\
\>", "Input",
 AspectRatioFixed->True,
 CellLabel->"In[18]:=",ExpressionUUID->"e5a348e6-9515-49d3-bd58-6244fbb25727"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwtm3k4VN8bwO1JSlEpUpREWiRJJeckaUOSJIpIka1kF1FJkrRQtNl3RbJm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       "]]},
     Annotation[#, "Charting`Private`Tag$1918#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwtm3k4VN8bwJkZJSTZqZSKRIsk7c6rIkmFFNkiilS0CElFUSppQWRJlJSl
JFJZOtmyJ/u+M3fGOjOYsf/u93l+f3k+z9yZc877vvfc93Pdq3jG1eQshY+P
j5/Gx/ffX0k5/ZH58zx8zql4m9FGGmizU3xUz/HwVavW8QubaOBUJiF+4gwP
h/zx9HTfTIMX7268vWPDwzJbz2S7qtMg61aHZqIFD6u9voLNttCg96RuUe1J
Hi7zDrm3SYMGoupJZvMmPPz5WzltjOQdi5Yy1h/jYav36vs/bKXBmW53L9PD
PHxAdmDvYU0aBGa1Ct85yMOTh3aPtZL8LWRf9Mf9PHyN4XbWehsNOi992FSL
ePiyJN/zcpKFDoriud083GF2yl1Viwaaq9yM1+/g4bOfl0p5kGwz2dR9XJOH
x/wqL6aRHFCN3G6r8/D11EO3Wkn+khQv8HEDD9/1MNYbJ7nZTzisRoWHdz8p
/jNDMs3misrcWh5WFX/PzyF50/aGHyqKPKwVMs5pINlcbO/h4yt4+Ktow+sk
ku8y4lpvyfGwD/M2xYXk5DxBlw9SPLxtbtvKlSTXR7rMVy/lYeegU+O55Pz5
rtc+m13Mw+JHLf2PkKx6dNdqFSEe7rX5/beUXL/pujdfTRbwcKuxcp0Wybf5
FujeovDw33U7Xz4n45fQdKE+YY6LF5vkSLSQ8a1K++dYPcXFSl8fHZUgeerx
9smZCS7+GPPk4C4yP0e1qctNRri4PfmwpymZT0+Z8yneA1y8+4du2kEy33Gj
ldoJdC4OUuV8Wk/Ww0RchN1MBxfzq/0Z/6FKg1XefBzlVi7Wt63a57SeBgYn
zvkZN3Lx20Mm5gIqNIheqJHwvoqL+RrP9Qgr0aCoM2zHv3IujhPysbq+hgaj
P2ZLpou5WExsZXyFIg0OXCwZNPrNxf2H25INFGgwWGWrMf2Fi30NT1e7S9NA
OrEoX+kTF28zXk41k6QB3NtwwiiRi6U/mkgpi9MgeBvPIz6Oi7Wqkohni2mw
K+JpzrFgLqZdk3r1ikoDh2vjR72ecrGiv/gaFh8NggwtO9895uJbwnHx2+eo
0D2nTJ26x8WWV57EPudR4aF9rv47Ny62QKm1Nwap8JIZZ+h9mYvTPNUkaAwq
vLvywMj0Inl8VISrVx8Vcu8YmdMcuNjU3/qlWjsV2JHdjg7HuVjuIt+mN5VU
mF/958KeY1ys+6J16HEpFUQSk1wlD3OxQUvShH0RFZS/u3kU7ONigbfFU405
VLCoXfBgrQYXv6yo92xIooKj5cCjmY1cfFrfWk05gQpu3X+DatdzMSdY8pRd
HBWCRsNf+ily8bkOG53ocCrki6i97xXj4oY7lUIb/KiwQfdY4buRCcyYgMXJ
ZlTYWb61xHtgAvvZOXYXGlNB77hshSl9Am/9dSCl/DAVbO26amkdEziqp1Ev
FlEh9Na1XofKCXzqF+uuozIV5jLCqEopE3hJ06Jjl0cpUKXcqRPvPIEP3dgu
muVOAe2CkT/55yZwQIiks7grBZLt5o90n5nAeWHzRhaOFHgQpWCx0nICX1rG
x8gyI48Xt7766vAELvXfde7PdvL42aa4JxsmsF4YiC4a54eHtTVU9+FxXD3l
tz/AgR8mrvQ8DGGOY3pwQckCS35wWMJZ8rV/HC+MvXLCw5gfwEB8+Wj7OLbZ
+unrJm1+4P0y0nT+O46DbDzEeNL8cC6pwsEmdRwfYK+u5y/ig313/xTqXR3H
Lnd33bWS54P+nOJiT5dx/DPs6ePLS/jg8WRJWaLzOL5R0Eu9QeOD2svl/0Tt
x/GqjPZFf1vnkePpf231x8fxutyDRjfuzaPAPS3j57aN4xfzOo0p5XOoYWJY
6QFvDAcdzROPOTaLLl6Qvv/n9hiOXnzorYLiFBozfTn93msMS9cbC96lTSFv
bekr993H8M2zf1400CdR4FJpK12XMSy76OgJi0+TKDlTSiPfegwbK9i7/9k1
iQaoUu25e8awzFXV5kfGPOQcJaH1bYqDLWi3uw7fmEBs/+Ck0AkOlj1wwOut
5QTycpVQvM7m4Jthdl6TeyfQo30SIppMDl4/p/gmjjKBEgnx7i9NHPxymd4t
7uNxxNQUD0r5zsEr6VLmq2PG0PkKsf537hx84/IH+fQyNjKpyGorvcrB8QIl
Re2pbLSr4lzdqAsH02JEQ+RespFIRXbBHkcO3vHlk26eLRt9Knd6W2vGwRV3
QkI4EyzEKcO2tJ0cHO7m+dp7HQu1ll0wV93GwXfzHlXyibJQQZm0kdEWDl4h
XWoVOzaKXpZdRFHrOfgkVW7Z7rxRtKNMVkFTnoNjwoi3TJtRdKv0cov9NBun
CYt7KGmPoHOly2oectl4ve5f9eglI+hoaVHpZw4bUwac7S91DaNVpct/Tg+w
8bqlGjtX3R9GeSXF4cGtbKwiGhEkVjuEFpasOpmfw8a7oxZZ7/EbRKPFZUcY
P9h4b4GolYXVIGosdtdd8o2Nu7MEzXmagyixuFzT8hMbH02OFvtFH0CGxZ4S
nNdsLKGzQ7Lg+ADSLF4jLBfJxtdtU2w3qQ+gFcWVFBTGxhMH5FI2LR5Aw3/W
sh89ZeNgX3HfmWImev6nqmq1Dxtfo2W2L9NnIqvrU7smbrKxTPHlRbPKTKSy
Zm18iQcbR5X4Lvi4gInwbY8bl13ZeCAn6LlrMQMFbojt2X+BjV1zKpc9T2Qg
8+bSIzKObDx6ysLl8RMGGt2msDrXho3bXTXmZU4yUHbPwcDnFmwssr+BSN3N
QAHPr0w4nGTjy9qvhzevZqBVQwWlwkfZeHV2Of8Qi0CDEcOaHYfI9dup7NnS
QqDv+rIxabps7Oz6lOFYSCCjdxeundpLrjfTR/x7FIGWm4S2bdjJxos1e0Qa
HhKImM89yLeNjaN5Qtc5HgRKTyG+1Kiz8atN8sVLHAnkYym+PGEDG+93kju3
yYxAhov23PdSYWP1L6HPjPUJJJt5dvTIWja+MnDo/M1dBOp1eGqhuIqNb0Pd
aMpGAn0W/1EwtozMn6OPwIAigbxw96ZiGTb28ZA4oylDID0XkVeREmxsN54T
9XgxgcSXa1Fdl7DxeLK4MptGoPaS05f2CbNxcZes/vlZOkr0eNggtZDM1y43
JfYEHbkrfdVhUNg4KfPd9ycsOtpX05qUPcfC3fWna/YM0ZGo7wLpZ1MsHMGj
KvAx6ah5k7qP/QQLMxqUZRrpdPS+9RRTi83C7jVIorCfjq4+umcqNMzCV4Jc
9vwhWXtHSm4bg4Vj9GxetJPHC/XXq3zpY+HVonpMIfL36oP5gv26WNiKEBg5
TI4Xp6M6a9bGwvyRtoqx5HwujRx3VGti4bw648ZFXDraEX3r31wtC/9V8tHx
J9dDO5ywu7qKhTXnS+zEBQhUxauKjy9n4T/Tg1KpZDyi3k8tuVHMwiP6ehLW
ZLycTNd6GRawcKdsEiGzmkCalKO9KzELozKz+XYy3uXWsd+LMln4S3FyxyMy
P+HCZasjvrKw6k7Lkgtk/hx+jAVe+szCe3XytYzJ/M5I6ttJJrDwpodr3Vc9
IlBx3pUyehwLF3cKOQtEEyjkcuS2rNcsbPfJRKUvlUAbyocXnXnJwhK8+yse
kfXGuyHrtu0FOV+flneH2AQqWLevXTCIhfs1TkfwFjGQ1b3QtM/+LHxaOfqB
7B4Gerxrj+WsGwsPHnuSuCCJgYLum+3rvczCh+vkRCzJ8+VZ9dX1ZRdZWMTm
k9itfgZ66fyRG+7AwrvLKdXLlZgoLkI6RNOUhfdX+kRcSmKi71Oj5Re2srBw
D+Xy6aYBlKUnkm6ymYw3e6H7NP8gyn2xLnKnGgsLnH3ttlltEOWr2pxfuIaF
5a/aGpjcGUSVFmUCb8VZ+FyQ1Ln1m4ZQ78947WbWKPZeSo1zejuM6At+K/0e
GsX3dnReFKkdRkyTVpEPjFH8ffjoRxmBETTCFG+53jWKXxp8jjvlNIKm5H08
lv4bxfjfnECs3CgSu2mRqp86ios2DQrvHRxFe3cvWZ3pMoqXP9t3K/IDG72J
PvG413kU39a5Lrgjn41ofFFjSx1Hcc7yI7TeNjYqLVD5c/H0KPax5s9zlOAg
86P7Lq42GsXHA+qlFt/hIDe769+ebBnFgfbaBkfMx5DZkszQYmIEz2hf1li0
ZAJpfjhGXz02jGXfWH476j6J8oqbXjcODONMi8R+w+BJdIxhfzKoZxjXtnhb
a6dOImdVz8LJ6mHsvF23ZpIxid4kv3lb9WUYF6z6IVhqNYVEvrBO33Ydxtfb
GoQD0TTq+RHc2MQcwvm/97a9586gy80rnj3tHsI2mStv3xafRXNTCQd1m4dw
9MPKVNg4i2T3ZH9LLRnCsW+6e++dmUVHc3tDHnwYwkZml07Nl82in3nbjLed
GyLn/7syImIOvShrKHnWNYifRDRF+YjzQZfsd/+apkGsVKvPCV/BB+rnwnWk
qwfx3cNGe+JV+KCC79SPyLxBLLeEYftKmw8EtZo/vH87iPn+vpMZPs8Hd960
Psg+O4gNSveV78rlg4vXu3QJxgC2Tv1dPWbFD1l5v/nVugdwpanR/Yvn+EFI
LC7nUvMANhtJ2F/vyg8JiWe2cUoHsGNX6fs7d/mhu6Nn7VzSAP58szpOJYEf
Thn0UyVdBnB7+89LxUP8oLdy4DdiM3GUWO6vQbIfo3z85PGRycTClZZ/HT0o
8Evj6kaJHibWOmG/pPY2BXboTYb31zCxLO/49J0nFFC9tPDykwwmzvLbfHdt
IgWWZK1RaPFkYiNFyefhnRQoP0CvOXCFiZm0tddX0ykQUJn48NN5Jl54+cRc
1BA5XveWcV8LJn4lc7TTfooCY4JQrrKHicUyPwrukKBC40krL/d5Bh5ZxneG
o0OFkM6V6p1cBhY/f17I7yAVjJ17+g6NMvD5gEvdtCNUKL3lbLyii4EzVUsW
NJD9bPY7T5WCPAZ+MMK+kH2RCrHskPql9xk4KvKw7v1gKth4mwfevM3Aiyxy
uNJkfyy/YPm+PncGvrB0142wKHI8ubcp3x0Z+F7GfI1jPBXuwxe/04cYmGvQ
bqb7jQrOQRUaKSIM3MnnbTpSS4Wha0EVV2gM/GblgfmiRipcPnXMSWuGwLfv
nYXHrVRwX/sv+tcAgSueT1xu6qHCvZ+1gtWlBA59pcEXyKLCgjehb1/mEThM
q+ffnzEqPPI/qW35k8BKcToSo1wqPDNqvNb7kcCKJbk1AqSfRPW3tE8EEPh9
3K9G3UU0WFkedSPLh8AbOavTe4VJX/tiLenjSWDN3xc7XEVp8MG749AiJwK/
etckc1iCBmpn3vRWnCawgIypQqQUDT4dtLvzwozA0j/sHRtkaJAh3pO+7CCB
I1UVMiSXk37Oe3usU5scX276qxTpY9ltDsx3WgSOc/nHoKyiQd6H/pWblAls
1DA1Ekv6nG5Qwk/2CgK/sbHIOk76XvE1pxOZUgT22Vz+laVMg0pt5iMQIHD0
abU1bNIXjdcmKQnM0nHzhvlQUzUa1C66iEvG6HhGPm3j2w00MBvZYBk0SMdj
F24SbaR/NtcOjZv00nFAaEoBjfRV65+fnsm00vEV9A3LqNOgM8ZVrbWGjmN1
FFqkSb918FcvelNGxzFxD8UppP/SnVm2Z/PpeD4082wTyc5GadPrs+hY6Obd
mijSn4e3XXs5nEbHF1o6LAxJv76yTHPL10Q6lnbunKKTPMY3XuYRR8e7KKlp
rqSfe/RnnNsTQcdm70N9e0ieKnPn539Bx553OOf2k35/68v2qMKHdOzbqnfm
Kcl8YTytR77k/LaoXPtD8j3vH/+O3qDjHpnDrwZIXnDG66LEFTpuMLxdO03y
o4O7FzY60bFtWtJaHsmLN87ERtnScdjRxoedJD8Tz9ljZ07H9YfX0jJIluTd
alAyouNaXmnwdZLD2rSvMg/S8Wjx6p2rSZbPnxf5jOjY3zR67Cc53+gPOOHa
djp2PfWnCJG8Ksh3347NdByVpZ+aSq737bV9bTPKdFzp3/tlMcnKp6ievxXI
45me5SfJeH3ULhC/L03HXgfm+QLJeG5Y659iIEquTzbQKIWM/9aRBT01s/04
Si5YN/2/+wv8CneVJvqxTajWlZRNZD1JbFP0GO7HARv3Hwsl83tgh/1p+Y5+
3BfesW4LWQ8BBl5zFxr68WOmnlIfWS8VVs+jc/72Y33zouYHKjQ46furxRb3
4y2XY9xekfUWEVzvlfa9H4t+vG4luJYGHfFDcrQv/bhSwZp6bjUNnEqXmSfE
9uO1EnteDpH17CXhWTt0tx8nbS4S3kTWf67S02voZj/2rlFcJ0GeH9Qd78Wf
X+vHD9fbSdDFaRBoVWuk6dCP2XGzTpbk+fU6Xr3CS7cf03osTrrTaNCdefBi
+d5+vFBtVLeanwbrSm2EFbTI9Xs4r1gxT4XU4cBDv5X78Y1Rued3JqmQt51R
uFCwHyvQ9QY8hsj9wIDv7Cm+fnxG/cSNw0wqHLaSoSXx+nBQwW1hUToVan10
9x1l9GG9g+WHbTup0F8SmxtS2ocPSt37tLOaCqqt36378/rwxzDhv/6VVHAd
/juzPasPP/dYLfW7lAo88bldLUl9eOHogbUC+VQQsrLIVHzShyP389Xkp1Hh
qMuVk9f8+7B5ovC7h5+oEOwTMF5wqw9brjv9WzuRCsvjv211cunDhbhy3D2W
CpuGxVM/HevDg3qibSufUsHEp+zDbvE+/G7hiXhzRypYD3dsIBb1YWMOZ+E7
Oyo4WY2lhvD34fEHG3e2WlLh9o4VP4ZGe7GW2qL1EkZUSBx1KYn524vj3VTV
o7ZTgWonzqQ+6cXhVuqVq6lUEP2r7JLqR37uBIfQDAXk9+5mW3n34pDq5esO
jVNAXc5hKuNCL270v6OpRF5/rP5lCDkZ9OJNd1Ny5ksokK5zSq18YS8+2lu1
WT+QvN59vvTZc74HBy7XGUF+FChdcXerErcH2/yYLFDypkDnZOLu2/09+Mv2
Z71ZFyggkjZzWL2wB++u/WgqYUABh9VvLobc7cE5l9POe1EpIEWlp1jNduNd
XwmhwPP8EJTSrqY+3o3v0NO+PzvNDwvM6z9Sh7rxnotX2v1P8AMvuTA+sbUb
H5c98U9Hhx9aT76L5mV1489WD+QosvwQl2j3JMSrG7sq5dal5fHBJpPWi+Xc
LvzL79Jmk8V8oB/7T20PuxMPxEbcWsSbQXc9V36KYnbi/THTF/Q7ZlD2sUvq
s92dOGnVxojrRTNIfU5wW25NJ+7anOAaGTKD5CxBGzI6sahevZq8+gxiSn42
OuDZiWfKHnWIOkwj+aVyA+EzHbhmtOy+/u9J9LYj6PYPyXZ870tf7S+bCfRO
V+mIOq0dh3XfN1+kM4HeJ2UtS+C04bOq4l+M10ygDx7E95DqNrz9JKOpkz6O
Pi3Zx3F91obv2n05vPDKOPqJxh2VRdrwyjNu/UP3xtC/GEvjYGorLugLJVxT
2ahagL1SiNOCP0f022UEs1HthYBhn+4WLGItqS/qwUb12zMeu/xuwY22P/Nm
97JR61/RokN3WrAJ7lo3WM4iffL3Lr7pZnzojZRF88gomj+tsvYSuwmfOqB2
T4Hsp/1WXpie7W7C+PwLSvr1YSTYkVIdVNOEDbb08yfqDyMxm62+qelN2P+U
xBweGUKrrLTbOe5NmLE9YEnHviH0bplvhp9jEz5j7umZLTuEVFryA6XMm3CD
dfNq0ZFBpG5xaPf2nU1YsuFpvGz0INIxNw33mm7EjNOsBMn5AVQkE+YqPNiI
M3P2bm5vHEAGDU16Ua2NWLvE5dyWrwPI5OTp8ZycRuxr2jx95/wAOmPqbMLv
04hV1/9ZJdLGRP0SKetfXG7EzQunzlzJYiLnmhG+NXaNuIrqWuoewURXTa5/
PrCvEb+c32FxyYKJ7hn5iATQGvFqvRZr824GEhTL75Edb8A7LjyMX1zEQIF/
BbI+9jVgF22u241EBgo5+vh8WVEDZgjq+N25zkCyopVgldmAy3JOrVhpxUBR
FWKyQwkN+PyrkuE7+xnoneHLItGHDTg59/q9p5IMpCLSFB1zowH7VEsc3T9H
oOSyZdfVnRtw+bFy6zyC9HuD2DUmhxswV3K2UA0TaIdQ71T3bnI8eal0+RQC
ZZcoV1/b0IBtzXzE2iMIVKif7BO6uAEPJv68xfQkkIHgiJnyXD0+rK/4Yvt5
AlX+2bI5c7ge55+Tl7ezIJDJA7cF+h312Hk/pdvJkED1epltjX/rsVuJWowR
IpDFgqn087ge76idH5bbSvp94Z7AqdR63GOvdLJoHYHO+N+xfxxbj6sLviKz
FQTqP5C3a/mLeiz01nWmQoJAzjQB8ZS79fjXlESemjCBhvMPMvZeq8cm5QmJ
V6gEunrvEa60r8d1l7q+vpmho4l9FWGnTeuxvW547o8JOvKiiLmOHqjHGQm6
QTmkn8/9NtHz3VaPwS+0OJn097u+oSvElevxc7eF4w9Iv1+o0zgWJ12Piz+/
8T5G0JHsd6mXDIF67K8knMDupyPVzce3q4/X4SiOdFcSybvfP2t0763Ditvi
t92k05HhisobOTV1OOd4o58tg45sQoSX0fLrsG3pej/LQTpyFT6UbZBWhzPH
o3IvjNKRz9371s9j63BTjGjos3E6ejGZP9fwrA5/LXqjXTJNR28v879R8KnD
bSM6JZLketPp2jpnXetw1pZj8lfJeBTZeHcn2dThQtaxkQ5JAjXU/bjHPlKH
VTRK261WEogw5K7dubcOhypvOkVXJdBUvmbRnQ11OPZjw8db2wm0PO2z4GLh
OhxcFKFfdJxAG9cPfTw+VYsfzSnfdrMnkPYb1cMRjFr8oMTWUtmNQHZB8U/W
FdfioJdfbj0OJ+Mv0LPJJbMWH73yOm1nMoH8vFdVpb+vxbcLC690kfX23jlS
fJ9/LZ6zunVUfIhAmV2NXwPcavGFb+IvQmkMVGwufeKvfS0WT+F8WrCCgQb0
nodZ7avFapJ13fFGDKS+5sFyj/kanCdrleSdx0A6EQU5OcM1WNDlz2+JLgYy
WUo5TWuvwfHmJyVv8zHR9Xnv2OfZNVho8efjuTpM9LPlqnLyjRpMOb/h9MMK
JjoQYqPexanGUrttbZQWDqITwlH/1vVU4/FFx2v3bxlE5+42XXWprsb52Sh4
xnIQPbxsmjGdWo0PvHDasPnrIKo0NNgl7VKNo4K1TXc5DSFzAa0Dh4l/WH+D
yF4J5jDSHd/Z1NHwD5vdzz5pt2wEafTtdXH78w8P/+jUlzgygoQLdcOj3//D
nfpRYuFfRlCu34nBEYd/eDrZ/boLGkVraddDQrqqcO6CFblykizUJeBUkpXx
F++tWuj+sIaNxPkdhLoiynDOiv0xOt4TiBVcoKvtXYat6hIvFoRNoCplJd9I
6zI8wS5cqPt1AgUZ9nNPrCrDOruaNmszJ9CicKe+0vhSPHdS9MgCcy7i23wJ
p6eW4DKeRlesBg+NWLm7BxT9wVv9ffo6uiZR+feA7s3sfHwqg3tiifwsKvzZ
/oVXlY/32D37Xa85i3KzNX1/f87HAxkOZwKOzaIvuHPl8Uv5eOfLIZuPfrPo
ZfEOa3ciD0cUfVRsHZpFpxuJhuz23/iM+NcHdVlzqGfkeUTwy1/YlDhCWK7m
g3rO3p1Kpr/wzhGFa+qb+KCYy2j4tvQX/pU3Pz+xkw+S53WkmgNz8bT0g7JT
xnzgvoT9dNW9HCxjZtF37Q7p/5tN/FNcs/C/boFIopG8nruIX/6jn4klZKNr
jXz4Qa3RdctvoUyslhPTG/aQH1T2VbB/ln/DNjLbcdULflgtHXD9k9E3rCQV
/14mnh9kcme9Qs0z8FM+jUpeMT/wiTL87Z2+4oBbL6pmF1Ng1kPvoLXqVxxv
GVNqKU2Bqa63gmaDaThTv6QyUYH07wybxwaX0/A/rbziZZspQFjXPtvi+QXL
rpI10j9GgTjLO9vnl3zGXM/Oc3lkvxS1eddPdvAnnLJAZlothAIvqeN7+mU+
4bNrtrP9IynwOMl5X8XKFFw+V90tlEgBt+kTRyI3J+HttSpFZkUU0I3cYL/9
WAJ+Lbc0cXyaAuBK71OteY/F9iestKNQYdf+OCcFs/fYseHZ+WxBsr8ckHER
OB2PKzu5p/ZJUUF6N/VGjctb3P/tzN9HG6nwN+Prio7lMfin0qILC8l+0nvg
2en49a/x4ciEYGNbKqgousRe0IrG13x3/np8lgo+gSpKvGORWFxcZkGVKxU0
7KM3LL0Xhn2KHBLC7lGhPdzLpeHpS4yjM3fbBVDhcaVZanRUKC7Ob4qTf0KF
3p3imqrfgnFZELXG6iUV1BRFPe5XP8UrFb8qKnyggl9g8ZT44BNs8S0j7Wwy
FVq5d2/HCATikB1PBqJSqRBUyfX/viMA/+PPh+bvVGDf7AphvvbBPt8nWE+L
yfldOKI2kK6HH6984NHTS4Xym5sdNEo2AcugxXwNQYWvIWmb8kSOw4jFyUiT
AbI/H/GfnPnhBDGrGjXvsMh+OXrEJuLZTVgcLnpSbJbsx4u8zHyt70DVjaWt
paR/VHEpKpqhvoDPXE1wo9BAQTFo1bIz/qA718f/ciENsq69W8qYDgTbUJlr
S5bS4Iwg84lVdxAY81H+7ZeggX+ljICTwzNAyMfakfSjDfbWvi0GL8D79BHe
TTka+Gz0QVLawWDq28h/aRkNarhxs0e3hIAbx1X9yArStwKJG3kyL2FzkvRY
8yoaVJ4U3jEjFAbZPD7/ANLPFBU3TWybCwOruBQNJdLfijOuXf3Y+wr+KbS3
qq2jwXKfl+o9DRFw605LXSjpf5cNfgwvL4sEL9Og3mHSD2U65pyffYkGr01d
e1w20CBc3f3hpR+vwUzzVHoy6Zfyd4cSDH7HgMLru3saSP+sPK/RE+zwBjK+
FNQMkX4aJO5y9S7xBiiScZ6j6jQ4lvWR/8rFWDD88319B+mzYg59z06PxkLS
+ry+H//9f11EcdVRtziI4bxI8iF9+HmG1ec9vDj4rbXMayvpyyY24dpq3m8h
2uqcUTXJ4gtrK+T43kG4UuTG/55fqPm8xFrQ7x2IfZgWqyU5xPzw4MTCeLhx
rG9Si/T1E/wPbvY9joefLVV0f63//v+dJ1S75D08sTVpxv89P2Ay9yov+D2I
6cr9o//n+9M713+RSQCn/aNlU/89j/Du+veYyAR44JRTOkmy7JEvB4NWfoCl
kncrekluGh+s9377Aex4FrVZJEe8Vjl3Yd1HiJT36bhNssVBh/FTSR9hrvrA
yEaSl43G+OlvToRNFTK0EnK+reEtEtu/JsJXwXsKRiRH6ci8VdqeBC+b1FA+
uV5rpomGZFYSiDOqz60mWSE46DcFJcNZLdOXl8h4te8uNWLlJUOpTELlOzKe
Mb0CnR16KRCwu12smIy37RMd18rSFFjxcZ1NA5mPVVq35rKPfoKwvPLMajJf
cQ/Glkec/AxlRxtDn5D5tVdXTw5o/gwVZhYrjpD5fzGYEb17cyr82uOayVMl
8xHK2qD6NRWWTWWoSpL1k3b+qZvieCrw+bYv9FOmgYT2xmzZ7V9AT/fBfAdZ
f7X9TocXZn0Bw+tuB60UaaCZtSB4buYLxI88ivJeSebr6bvmce00WFFaKPWQ
rO8TOzrP9+alwfFCrzvnyPOh/qFZwO/Sr8A+9s53qxgNtGzG/34XSYfFip36
GYvJfGkEy6QeTQdO4WfDNcJkvloq37+uToegN0dkCwTI/GzQK7zZnAHF3vbr
5abI/ZG/V+Ta8m8wRlhpz05QIaLO19TZ5htM/NX+XMGhgsXtnB7z7m9Qe9Ht
29Yhcv/5q0nRYmaCQVdBq2QHud9pK64rXPcd2ncufxbVQoUHyYsNTc9+h718
WYckGsnPH/aHXu38DieJuc6KKio83Be+/nP9D2juCFnu+ZsKWhnTRir5WfDi
wY3xdzFUCFxDXM/ky4ade8f2rIykQtfz2gg97WwoEFVoCiD3x0CXlF6HH9kw
vWehsiq5f3avO+0Z+zkHfB3fpcffoMLTiLwY+ahfYBE4O+9/jNxfBT8XfGz6
BSP+xva8Q1SIzqpwixLG8HKL8R2LA1TgrP/5Su0QhtdLj88O7aDC6wXBPYcK
METP72w2UaTC2K8DHvd//oZNgZUJ8iMUiNX48Hr+fT7ELgjMbrlNgbQplWjL
4nxolB7RTHOnQF7ex8hMRj5I5i0vcXehQK9JUrjrhgL41QcepdYUUL726UXH
lwIwO0E3id5NgcSv6fd/ZReC0S/3HzMcfkjT/O1yp/oPfNfmF1xozg95MzqX
Wjh/oKeQzsk6wg81BXkXtksVw7qbk/9s9/PDmGmB04hZMXS2bfnotYkftK7/
OXO6rRhK5eqSR6n88DOj4iQiSsC5+U/DeBIf5Gk1a8/PlsHIm0MmjV3zaPni
yhO/FMrhkuJ6k8mSeXS95/fFO6gcmuwPKfKlzSOVZx8j5n3K4YBFfvMv33kU
xPCcmKdWQLy39lORVfPIIkrmE59QJSzzMeKjms+hSZ9EUX7hKtjbrZOd9W0G
Pe+n36LIVMP0Ev3VPbsn0R7PDB995WrYk3duVERxEvUvuncvaFs1dLy7LrZx
wSTatVHhobxpNajyqFbGVTzUfc00RON5NQQIeBFbHHhIg/934hnhGlj75ZBU
yCMuqlkW0ZA3XwO9ox2aK2rH0e0Ux2bBJbWQZtNvmPh9HKmgbW1HFWqhnmdo
uyN6HHmfqepu3lMLazyH1p46N47WflwwzL5RC2qUcY0fvDHkpnWNtmasFl7w
Gh+eUhhDUsaGW+4RddDbZvIt/TIbaaitdJaYrIOZ9Ufs5E3Z6KgAO+7tonpo
nxO9FrqdjQJ+hEkWqNaD3KNCi79zLDSj2MOlXaqH9PG3UheDWKiXfSP3Pqse
1l1SeKv8dRTxVxhypSkN4CtMSzoZPooUElaqJ4g3APvqWbvkW6PI3LIw9s/W
BvhxeFtohf4oKs8X8xd0b4DCr8O54nkj6GtIwuFHUw1w/Pv905LbhlGVi5ef
vHAjSI34qFgJDKNB/SM5icsaQXrN9hm5+iGkPMveVLanEdzC9LqoN4ZQxFlt
cZE7jbDB9mEYvWAQZaKlh6OeNkJYWYed1qtBVCvXe2/Dm0Yo4q1ylnQZRKKV
D8cNfzcCXYl57bHcILqrVdf4hNoEgkJr0vM9BlCM2IelCpJNwJ8Y5ck0GkDZ
TC+DT2ub4FTUqzdZqgNo4vWq7ErdJtjQPr/wQicTOS+8GLMkoAnEPTyFbE2Z
6EGXdmNMeBPc3+cRt3srE73LWrpU/WMThP3xv98mzkTtrpl3jUqb4M7hQ/O+
tQxk3Eg591ykGUatL/1LtmOgQfP1LxcubwYaK8KvQZ+B7jcdK7ql1gw50m3K
ReoM9LM5StnZoBk02iovTFIYyNQy/2TnqWaw+U0X3E/62nAL4/7J882g4tPx
wKKRQGvatOj7ApqhhbnIdyaVQLnW1jI/wpqhLTzB+/FrApm33zu4OaEZyodG
LViBBArsqEpYVtQMzVKWE4cuEkjZltvwvK4Zrl29GQnWBMKdKwQF+5rhaY0F
S+oYgca7nJ3GqC1wM/ttgP02Aj078zzcWaIFXM8umWpfTyDVnsziztUtELfk
uRci/bbAvp13UqMFqvL+2d2XIpBNL219hU4L3HO2G0wXIRDPQe3UfuMWuH9f
cHc5jUAv+owf/rBtgbrr60wqZulowznPH5svt4DgxrVyP7h09Kf/NSP+TgsM
ytJPPWPT0RnHQrnlT1tgT6sjPj5MRzP0gUMvXrdA6T2DZuoAHb10EvcS/NQC
LplPpGMJOlJn7Ei8nUN+38ygUI1OR6XnTzePlbfApW4/mXf9dOTA9Be60NoC
q5vFVgqRn885J+/qGmiBltP3K63J778aqHY2m26BdgGDyddMOtK8OBlRIdQK
hnXvj1cM0VHl4Mqy/fKtkGs7dZVg0ZHTJb3pH+tbYV8Cu2Jkgo4owxfV1He2
gsLVtuzuGTqKcgm2fK/fCtlY0AtTCaQ18uPxcvNW0Pu1dXWAMIGqXDuzXji2
wtvPSzJ2SBLowuiCQUGPVrgjWyX1bwWBFlzZuPzO/VZY410ibKRCoDes44bj
oa2ws3jF/vStBNp11cv7QnwrOMVePzKDCFTLfpPcld4Kb94UxikfIZDLtT+t
ZgWt0P1EIW6LJYEEx4ZEKmtawS7ywYtlzgTaO77r0k92KzB2VI/4PSJQ43W7
aHVKG6yezPDiiyLQ1YkHFe+XtsF3g3DN458I9J5buzFYvQ0+OHSFXq8jEHhO
Wy+CNogrycXAJFAzTzHozrE2YKQ+W9M8T6AlUy7DF1zaIIzaRVzayECJXqEK
3bfaQP/OZ1N7XQY6MJ111PxJG/y1XrZ4hQ0Dec4Ifj6Q3AYxItJj1c8ZqGsu
znUFsw0cvTPuz/Iz0ZsF1GTdyTYYGjZK0FjJRDai9sQlwXboFtSJWbKXiVpX
rLHLVW6HQENx929eTFS/563Jaft2uKfzcOTiLBOVe73dFtvaDuM4wFhZYRA9
vku9WjLQDik3WgVeHRhEBo/sP7Gm2oGtVK/68MIg+vNqzbp9ch3Qc0QnuOHn
IMr7/la250QHtOc7JffbDKHvE2+n1/7tAH9WqtCXn8PIY46640h7ByxZVXWi
jj6MtBY4uF0f6gD750OrjKVGULPQi4lugU7QE6pK07sygszkTVy3ru0ESmJF
v4f0KDLZWW1ba9sJ7sysc78bR5G+R/V+6eZOKC28GZx5hY3sVgrcOtbdCfNr
pu5uDWIjrz/bvwUwO2Hz99HqvEQ2SpKJVpme6oScxEtHZXvZSPS74+LOZV3w
2dQsLMCMg+p4M/UfrbuAq9D9txHG0Bmvdc57u7rgrca9qI+yE8j7lvczB6Ib
dk1HqR7Gk6iWZ14oNtoNn8vXHaa0TCI1t21T2dxueHLzfH3K+CRqdh62l1rY
AwEzWzZ1qU6hHea224uUemDDiTLxtJApNKZxoH2dfQ+0fPB2LD47jS4QwhsG
2nrgAx2IAzMzKM+esA3r64Ex8xuL5aVmkXxHQej+oR74yPWqbt04i4rrbs1H
zvTAcnthf9XTs0g5f6TacFkvfEq49a4Lz6Lu6Jobn8x7oeiRQXe4zxyyOB75
50pNL1R6nn6/ZHQeDVz1kslv6YWIUCVjcRofeL845SjZ2wuRhvNLl4jxwet/
Mgszx3qhzjmf1rGOD7qOhejNSPVB6KrTpvUn+cDJ8EnhffM+ED0Q7yyWxgfu
unfyI9v6oJt/5ISqNT8sPGsjMdTXBwe1auCkIz+E++211x7uA7FoYtHVK2S/
kz9N6Zrrgw69peOe/vwwq+O5T3lVPyS+iryYl8wPftpXfqeeIbnOVFeLxw/B
2+1/FdL7wV29VmXPXQqcUR0UejTSD+MXOym/HlJAY8X1k0e5/RD85wzSeE6B
asqDofoFdJigf/zOiKGAWGXiMkKJDvJOJTGR2RQIdGB7CDnQwV0tewOVQwEr
s5v5lRfoEPtlXdmDSQqoGdCWBF+jQ3NL2K6ZeQqUbpZ+v+weHX5JX72QLkIF
wemdtRvi6KAQ8lHDTon0/+e+6sc66dD4IOtZ/HEqmPoJeUsQdNixJ+LpmlNU
WOMR/KdhhA680ry+ZzZUyLOKt7Gdp8NYeaL3zvNU4FMpCbyiQMB6456I37dI
X5c3adymTMCpO7de/bhLhZjFLWumNhJQt39N1psHVNDmDP68u5eAqYurju15
ToVbuWKMYCsCtBzTJT68pYLhl1ea5g4EfLbqvCf7gQrL3632WX6RgDS4RXgk
UyH7oaZM/E0Cbp49e4OaQYUpU3PdbxEE6Y1H1h0ppIL7QExsYyMBJwLXOb7v
pkJjrC7neicBTUIKwpw+0kfMBw5IEOTvKbhSNzOoMFugRRzhEnC4dLDLbYSM
x+uKTflSDFjRYDq6fZoK/abXfGxXMKCs+FnV3CwV9IXlqmfXMuCTVDmRzkcD
EU+H6zs0GTC67UX6MOk/wcbTWSkmDHgTPeMQvoQGYwtjFx+2YMBHT73UxqU0
OJmrd5qwY8B5zp7lgpKk36u9oKy5woCaR1RDTVkaeHdtN8WeDLB6OSK0RZ70
zbC2eGsfBjjK487ly0l/pK0/FP6UASmXVxf/Jn2OllUZsS2MAbvULtd5kb53
7orbYPVrBnxRlWetXkOD9e2/ni7+xAC1y/WHgfTFRyFnuxIzGCBreuBBxjoa
DBoIb9XPYcCWjMISufU0SM08WX+3nAHqvqHWn9VI/3eZWbeqlgEvFnQkdZJ+
6rY27kZOCwM279aY5ttE+mLzwTKLHgZs9dA2ECP9dvvzoeU8Jjmf6aIwUdJ/
ww8Gu4SyGaAwEtc9TfLU7A6sMcWAVtuc9Y2kL1ulty+t4mfC0/1SF9+SPp3r
7Gd/aRETbrvkfLAmfXuVomqG0FImaEW1ti8gffxuw98FH2SZ8Pt8yuIYknuf
XDfXXcWEkRO3NZVJn9c9sCyxex0T3uEvJlEkv5/C03c2M8GImePIr0UDwS/n
jqzYzgRHzoZrJ0h2dhSJ+anNhLGWKLdwkstXpI2a6TFB+96vC6X/vS9Ra7Zv
/AgTvBIszP973uHZo9ngFyeY8Lrv4K7/nndgw9u+zdZM0PzhtvS/+xfHufrb
KxyYYOjd3fbf/Y30lOEA54tMuOP4Pqbgv/shDiHNC92YQHnBOPmMZE/5XRvi
bzKhmEVQD//3/kZVx61995iQZzn+foyc/54H/n87HjFhnd81eELy671qirde
MKF6rqVK8r/3L8aqrspHMCEDZZk/JuNxJtG9IDOWCZaRXxpHyfgV2C6XPvGR
HP/gNWNdkpVl8hzZqUz4SUplABlvxr3FwhsxE+4HpIa3kvnxa8/wcC1mwnBY
IaOBzOeqnTa9X6qYQA9+uv0Xme+Tw59ytLqY0Mi1/2tM1gNL30z1BoMJSTIF
y2dVaRD4dv5lFosJfmF+l0LIesozN7oMlAFwvcqv+ICsP+uvvNa7QgNguXb0
QfdaGvAWxx4qFB+AP8TbqfVkvW7OZ602WDMA8wtHRG6R9R21Mbju+IEBEO3a
uElThqyvgN37XhoOwKOtr3ePkudPdXfPp0bTAfi4r8w5XJwGi8I1A6zPDkDw
tbO7UxbTwJ1Sv8vx/gAEjI8uYFBosNT6dsLHoAG4srr17gLy/E3OVJYcfDkA
Sz6f3/vf/ceeix5DlxMGoGrjyG1iggpGDbJvvIoHwLDENCWZ3C8GtvwWyaka
gPaNOmEb+qlwP/D8jfnGAbh5MbknnNxvcnR+mvgxyO+f5v+u1UIF1WRLgSCh
QWBYNHQ+KKNC4QLa1SrxQfAqVLl84c9/7yskt4svGwRvXkPg7nwqhEnPZoap
DcLoRL1/7E8q0HxfO8caDsJk9B5Ff3I/jGnRa+gxHYSWucjCCnK/3KU1sl/Z
ehDGjx9aT42hwpUBtCLp0iB87Yk7pBlKhfYTXX/TgwYh/IpKWqoPFb6rrt1W
XDUImdZxMbKmVHhh7h59q3EQvkmeX/zyKBUu3i8W2No5CIXvd66kHqLCqu6L
9dEjg7DUptYgeS8VHrzK8LgmOgSnuxse7lamwknBgz8VDIcgTGWDuukYBdS1
Xq2uPT4EJUvbjP4OUUDIYeDRQ8shSDHWfrqLToHcX08tx5yHoGB5xP2uJgoo
eTTOlDwcgh8i/seu5lJgrO88uv5nCGR870gl+FGgUiI7QfXvECy7Gb5Z5RYF
PuiIinXWD0GEwTreq+vk9S86rdOgfwj+9i/LPnaOAvmm076rBIbB0IKlInCQ
Ai/yAwvK9g1DgbVs+hsBCmyJ/Xxode4w9NePfyM8+OHANVqFd9EwPOr9rVJ+
iR/MdU8ZNVQOw+KldgYx9vxwm0ExC+wYBgNHsU7JY/xQvuWkwwTfCNg7J2og
JX44lzdzu3T/CKTmyfTHVPJBRM+h9KslI9DLsmqUkuYDisTVp3bOo7Cn2uSG
6uQMqmtTNb3pMgoweaoyoH0GffjQIxt6dRTeSam/qs6fQUe0T8QVe40Cl/jo
sT5oBoWf35Gx+fEopM76VzAVZ9AmPNc8mzQKiw/tiGfpTiPLS4+VI4ZGoUhA
qLnHdxKl/3mXU32ZBfu7/rRxm8eRsrcG33s3FnzG2Uqev8ZRuDred8OTBcfy
M49Nvh1H3q9a/qz0YUGS4OaJ+YvjSPeCePXFpyzocuLEqM6PoXpRn/4Fn1iw
+vunbMu1Y4h3wnLJ7gHy931vnC2+zkbOQgxj0REWrPzeyGduyUatue4hXWwW
pAvLfp4ENsLrXsgFTLFgifeiJe4ibPRwsnhN3SI2eLCqxR3fsZB8tNYOVxU2
qHboW9WT/fHu3qV2b8+yIelG5EKB9GFUyly1peQ8G14PfTqx9N4wMmdt5h+5
xAa7oyfMA02Gkfvckdhd7mzYrs7c3cweQmmyj7r+3WeT/U6YgOrOIaSz8tUX
7iM2CG+w3sYnMoSqlD74rnjKhm1Mo7fWHYNoSKNI8XwYG967XdXMejCIVI5Q
zvB9YINzfECddccAyjy+VEM5mQ1NnADr0m8DSM9iFcUwlQ3o7IXuxqAB5OCo
HRf2nQ07XqhkMWAAxfh6dW8qYcPYv3z7PSlMtCngYZppBRs0bhrayz9iouyg
8Lte/9gw0rLg1DdHJmqO/La6qIkN9DjhDVpKTCT9jX3GmskGrZY2/O0jA8Vn
82+9N8wGM5GDBX2BDKSZL0b9yGbDksov+4YvM5Bx1aa3Y1NssFa+Ux2+m4E6
6/dek59ng18Gv6nOagZyaTPcD1QOQO/4xqpFDBTIdO55LMyBtQqmy1NaCLSM
dePrlyUcmPNdL89fRKBEbsC9BgkO8H+3hoNfCFRMS1izZjkH9C61MNJJnzQT
/sbRX8UBCZFbsV2eBOpfWpjvspYDjwzM6UJOBKKu7LH/uYEDdWJ95laHCPRC
ib21U50DCTeL6gN2E2jVBn7agm0c2OeW7vdzE4E+a4jVqu3kwN3M7F2c1QTS
3rnynfFeDhx/7/RJU5ZAFWiTm4cOB5yuJV/xESWQld7eA9G6HHgBDFaDAIEG
DA0l8w9xYDKG6rFnjo68jlv2Ekc4YF73dPVnLh0tsnBOFzXhQKqM1Ig6m47C
bW/4aZ7kwPSY0+c80v+VHQNMLSw4INawRvQsk44yLoWt9bHhAPLb/ESWoKMD
bu/H4s9woOroZf+2fjqq9sooKDvHAZFbD5XTSbbzLQhhOXNg56Ec9yg6HY0+
qHGQceXA1WTC5CWDjhQ8M9MmrnLAUUF8z9lBOjJ0iuSrd+fA+E/WqOIoOV/z
O0czvDigJDLJKRujow/69lEhtzkwFNDx4cwUHdXvOMi8dpcDRhMzpn18BKKt
V9tx/D4Zz+/pK48LEkhDbsl9jUdkfO6xxJPECGS3iFOzNIhD9j+pywblCPRs
sl6R9ZzMx0SUkNRaAuUyfrpWhXKAa/ctZO1mAg02vc75/IoDl/sETeXI/MiX
3hV+Gs2BTBeXYtZBAun/PHfKJZYD1nVW5sknCOSeaJBwJJ4DyrtzjQ86EKj6
kfh+kRQO1IQv2y/jRyC+mxPPBlI5MLLlsIN+KIE2XWhuL03nwIYy7f0mCQR6
fDjO62E2B568SkmiVxDo5+77xU6YA2u2pP1y6SYQoeYsrV/AgZt2rz4Ucgl0
QEQjbUE5BwoCA081rWWgqzNSfP1/OTB1f/Gm53sY6M3g5JHCGnK89+fZoicY
aKb8N+NeCxmPMb1W4wAGynhirMg/wAGZe7riiVwG6r21zbVzmAO7krZE6kkx
kbiLXM4vNgcMWU7mwVuZyOVol/ntKQ7sFrVV0LjKRMpLrjybXjQG/wJkl27j
MlH4s2fz4ypjsP3EkWf/VgyiIh+3I3UbxkD1de3K5bqDaOyyeWS6+hgEXht7
x7g4iIyMV22/tmMMuPf/pVByB9Ei8VSX0YNjUPHodXvX2SHkFfy3jXluDD5Y
Pr8gWTqMrvT9/vTNeQxer0FDF7jDyGl7+p27LmNQI/31rrzSCDJrCVeUdx8D
9uXN9m6+I0hzzZmzh/zHoPan3O1RhVE0nDY2mPB2DBQuPtnO6RpF9tVyMw6d
Y+CWGHZmqzcbGS51kO84NQ7SfNOhLPL6YJvR4DlrPQ4TYpz8J7xx5HbqcMOy
M+OQ1T0+s156AkXFaoSYO4/D380Qams8gQa38ItWe42D62LXke9/JlCgyWv+
wshx2J07kJ36lYvKgxuJxLZx8GFl+/b4TyJD6SOZ7nYTsHZloO4rvlk0/zY0
+OjZCVjnKxfqLjeL0ra0uyqfn4A4Uc8LOhqzSO6Iq0r95QmYPb1x/LX9LOq/
9/zVNp8J+Nw48dStcBb5supujr2egNQPOnX2/nPoW7kNXG2dgDtyrvRt4/PI
2SJhuUHnBOTsCz78Q4APVhAjPMXeCbiWe7ivTIwP/Ki+X/4NTMA3+72vKpT5
wHjX29VbpidgiXPkOh0TPhhMoNNG5bjw+qmaR/N7PlC8d7nkkhkX9I6rhZzX
4wfProXi3y25kCX5Rl7EmB+qUIwFxZYLR4Vo0dGW/OAzUzHw0okLT4+qGj65
zA+d19VE8Q0uSHvfsox+xQ+vnfpNxKO4cPHB5YVXCH6YKLoVafWGC3HclcLT
LH44qiTV+/4dF1Z12PKuTvPDbNf+67tTuJAi+d5ogyjZ71jGhjnkcmFt7kn9
fA0KyB+1av3WyYVOHd0T1z0p5L7DWcvfx4WAV9Seeh/S/4UeXzrM4EKg0vbL
Sg8pcOPPj7kOFhcWMT8cf/iKAo0go7iIygNansc/5x8UCNtafdZSiQdx1Fvf
Ho5TYPj5+U/x63lwYpXlwYwZCuiN8nFHNvLg4tdm8QoqFSaSNwf4afFgwd5L
G38vJftB5SeJKQd5ECN+fN/PDVT45LeWwz3MA2bbd0+9rVRY0JO1e58RD8bt
E0Nyd1IhI4ZZXm/Og6axHSeu6lFBZM5XStGaB6x16v0phlRwsJKzuWDHg+fa
jtvqTEj//5n6PuMsD06zbXcS5lT4//v/sG9FHtFvQ4X/AVJ3Qwo=
       "]]},
     Annotation[#, "Charting`Private`Tag$1918#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-100000, 100000}, {0, 3}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8113965341102858`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"c9fbb740-7b69-4a7a-86d6-f5d935b42d4b"]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{915, 503},
WindowMargins->{{17, Automatic}, {Automatic, 322}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"fe5261f5-9d1e-4b35-8fb6-2721071ef2da"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 96, 0, 67, "Section",ExpressionUUID->"68e7a372-2af0-423f-a89d-9014c82b299a"],
Cell[657, 22, 308, 8, 72, "Text",ExpressionUUID->"9719ce43-3705-43bc-b327-9ad9c849b491"],
Cell[968, 32, 6083, 210, 3738, "Input",ExpressionUUID->"ff4590b1-a226-44e0-963f-eb797962fbce"],
Cell[7054, 244, 406, 9, 76, "Text",ExpressionUUID->"e62469f6-7147-47e0-a9d0-edeb822093c2"],
Cell[CellGroupData[{
Cell[7485, 257, 461, 15, 228, "Input",ExpressionUUID->"857dc722-28aa-4132-99b2-fcba09c84fd1"],
Cell[7949, 274, 192, 4, 24, "Print",ExpressionUUID->"568da61b-af5c-4d27-b874-f4a8c4bc46ee"],
Cell[8144, 280, 263, 7, 24, "Print",ExpressionUUID->"baee26f3-dd13-4f5d-ac4a-fad1db128c00"],
Cell[8410, 289, 180, 4, 24, "Print",ExpressionUUID->"fe515c50-d2b4-4474-93e8-f1019f80d3cc"],
Cell[8593, 295, 199, 4, 24, "Print",ExpressionUUID->"544eb284-4810-4744-93d1-68b00095e906"],
Cell[8795, 301, 240, 6, 24, "Print",ExpressionUUID->"d4f2f228-d017-417f-bf48-a82d531fd84b"],
Cell[9038, 309, 183, 4, 24, "Print",ExpressionUUID->"317530b1-878e-4bd1-b3b4-f47fcb3aa7e6"],
Cell[9224, 315, 209, 4, 24, "Print",ExpressionUUID->"a1eabd2a-01da-4a0c-8baa-7ece57a6ab46"],
Cell[9436, 321, 255, 7, 24, "Print",ExpressionUUID->"2a998053-083c-4189-8906-18630a832f16"],
Cell[9694, 330, 181, 4, 24, "Print",ExpressionUUID->"84812f71-806f-4f54-9522-c3eb0a38e55d"],
Cell[9878, 336, 196, 4, 24, "Print",ExpressionUUID->"07464b55-bc3d-49e5-8dbf-f2485138f2f3"],
Cell[10077, 342, 196, 4, 24, "Print",ExpressionUUID->"a3ee8972-9301-4f4d-b502-9c28f5bc34fd"],
Cell[10276, 348, 181, 4, 24, "Print",ExpressionUUID->"3bbc281f-1089-46ef-bed1-97f23b025f62"],
Cell[10460, 354, 198, 4, 24, "Print",ExpressionUUID->"47bbcd92-5378-47ce-9f4c-b531cca42bcb"],
Cell[10661, 360, 240, 6, 24, "Print",ExpressionUUID->"6268d31a-c76a-4663-9435-83fc7084930e"],
Cell[10904, 368, 181, 4, 24, "Print",ExpressionUUID->"5f6f535e-bc60-40a8-b154-fc150d6a0e64"],
Cell[11088, 374, 206, 4, 24, "Print",ExpressionUUID->"434cb6bf-d670-4762-a278-09e3d9c82f2a"],
Cell[11297, 380, 258, 7, 24, "Print",ExpressionUUID->"ffa19731-a99f-4d8d-872a-812b97ee792f"],
Cell[11558, 389, 181, 4, 24, "Print",ExpressionUUID->"12b7fb57-0881-4a47-8e95-0076f6bdd9b3"],
Cell[11742, 395, 196, 4, 24, "Print",ExpressionUUID->"7ef11fac-717f-473d-88f8-d9924e92bfed"],
Cell[11941, 401, 262, 7, 24, "Print",ExpressionUUID->"3282959c-9db7-4888-bc74-f57e44e786f2"],
Cell[12206, 410, 181, 4, 24, "Print",ExpressionUUID->"d0ee8afc-0f42-42c9-ae76-8ba2bb32cd15"],
Cell[12390, 416, 210, 4, 24, "Print",ExpressionUUID->"790075c7-6185-44c7-bdbc-8ce77a80abcc"],
Cell[12603, 422, 256, 7, 24, "Print",ExpressionUUID->"1199f9e5-75cb-4a56-85af-9a89bf5baf0e"],
Cell[12862, 431, 181, 4, 24, "Print",ExpressionUUID->"dd7bde0b-d06b-4519-adcd-86bc4102cee9"],
Cell[13046, 437, 198, 4, 24, "Print",ExpressionUUID->"f976ed5b-922d-4c8f-be2a-870b9ab17c1f"],
Cell[13247, 443, 752, 21, 40, "Print",ExpressionUUID->"67a26301-b166-44b4-9d1f-182ff7398e70"],
Cell[14002, 466, 181, 4, 24, "Print",ExpressionUUID->"679ecc8f-4916-4433-b6a7-a9b14d94f272"],
Cell[14186, 472, 200, 4, 24, "Print",ExpressionUUID->"9d0f1f3b-71ba-49e3-839b-e4fef2dc8707"],
Cell[14389, 478, 750, 21, 40, "Print",ExpressionUUID->"bc8825b5-94f6-42ae-b828-335fe4d15d82"],
Cell[15142, 501, 181, 4, 24, "Print",ExpressionUUID->"dc2b674a-62d4-4abe-a15a-a4dcedb6dfce"],
Cell[15326, 507, 209, 4, 24, "Print",ExpressionUUID->"f066d13a-c05d-45af-b8f4-b23a38a19a97"],
Cell[15538, 513, 262, 7, 24, "Print",ExpressionUUID->"b6dfbf21-5f78-4086-9925-792c393bcaa7"],
Cell[15803, 522, 181, 4, 24, "Print",ExpressionUUID->"c71bc94f-cf4c-4fc8-94e9-f28e3b287c1f"],
Cell[15987, 528, 196, 4, 24, "Print",ExpressionUUID->"2d01e95e-24e9-467e-81f4-d1dec786c79c"],
Cell[16186, 534, 765, 22, 40, "Print",ExpressionUUID->"74ea6bd1-9b46-4f00-927a-361b725474d8"],
Cell[16954, 558, 181, 4, 24, "Print",ExpressionUUID->"9f9b9f6f-cccf-4d8e-940e-f6314c1d5fac"],
Cell[17138, 564, 209, 4, 24, "Print",ExpressionUUID->"bf660131-47ea-4cd1-9f40-4ade024983b6"],
Cell[17350, 570, 261, 7, 24, "Print",ExpressionUUID->"a1ae6da8-7fca-4137-b83b-2db8bc0cf5e1"],
Cell[17614, 579, 181, 4, 24, "Print",ExpressionUUID->"3a6dc0ca-1c24-4bef-a994-0034b4ad8bf1"],
Cell[17798, 585, 196, 4, 24, "Print",ExpressionUUID->"9d7ed026-846d-4b68-ae34-85a6e396c277"],
Cell[17997, 591, 724, 20, 40, "Print",ExpressionUUID->"79f31eb9-38da-4a74-a2f0-c39ac4286b09"],
Cell[18724, 613, 183, 4, 24, "Print",ExpressionUUID->"3156fbb5-8c6e-487d-8502-0a567d11a0c0"],
Cell[18910, 619, 200, 4, 24, "Print",ExpressionUUID->"99adcd7c-1b01-410c-8371-c4af8c6091ff"],
Cell[19113, 625, 261, 7, 24, "Print",ExpressionUUID->"ccf5c3b1-3643-4bd0-89ac-72064cf1a204"],
Cell[19377, 634, 181, 4, 24, "Print",ExpressionUUID->"09dfaa42-37de-49a4-9691-b8ac4bf2d694"],
Cell[19561, 640, 200, 4, 24, "Print",ExpressionUUID->"8e855058-f3de-49f2-b644-5b0ab3e3ba91"],
Cell[19764, 646, 261, 7, 24, "Print",ExpressionUUID->"10df05de-7d31-4124-acd9-c0732ac80b98"],
Cell[20028, 655, 181, 4, 24, "Print",ExpressionUUID->"5947a0ae-8fb7-4af5-8bf5-79dfdc838f5e"],
Cell[20212, 661, 198, 4, 24, "Print",ExpressionUUID->"b4ae0fd4-2425-4c5b-bfee-891eb9dbb54e"],
Cell[20413, 667, 262, 7, 24, "Print",ExpressionUUID->"84067e1c-3337-4cf3-903f-7a191132aa1e"],
Cell[20678, 676, 181, 4, 24, "Print",ExpressionUUID->"9783fb08-1e51-4b3d-ba25-e98e9bfcd72a"],
Cell[20862, 682, 200, 4, 24, "Print",ExpressionUUID->"303d07fc-411e-4630-8a9f-e7c3c0ff4572"],
Cell[21065, 688, 292, 8, 24, "Print",ExpressionUUID->"eeb25984-06f2-4d1c-90eb-e8b55e622aa6"],
Cell[21360, 698, 181, 4, 24, "Print",ExpressionUUID->"d8666d8e-d259-415e-b6c8-30c856b36038"],
Cell[21544, 704, 192, 4, 24, "Print",ExpressionUUID->"9c0a36ff-5319-40d3-b321-2c1dab625698"],
Cell[21739, 710, 291, 8, 24, "Print",ExpressionUUID->"df60c24c-dba1-4db1-87bf-381f0efe161d"],
Cell[22033, 720, 181, 4, 24, "Print",ExpressionUUID->"0b2066aa-3a5c-43df-8b4a-6544f2bac26b"],
Cell[22217, 726, 193, 4, 24, "Print",ExpressionUUID->"d6437445-a7f3-468c-a4b4-6e53d917d18d"],
Cell[22413, 732, 256, 7, 24, "Print",ExpressionUUID->"a3788416-04e6-4a2e-87f1-39c3298ed339"],
Cell[22672, 741, 180, 4, 24, "Print",ExpressionUUID->"d0ded35a-1fe8-4ccf-9bb9-d6b856990e04"],
Cell[22855, 747, 207, 4, 24, "Print",ExpressionUUID->"f266d361-e4da-4471-8719-3efb465d7920"],
Cell[23065, 753, 774, 22, 40, "Print",ExpressionUUID->"a9ef78f6-7b6a-4ab4-8a8f-de68b7e5596b"],
Cell[23842, 777, 183, 4, 24, "Print",ExpressionUUID->"2a024105-fdd6-43ac-b891-f2801f536d70"],
Cell[24028, 783, 204, 4, 24, "Print",ExpressionUUID->"5ca39519-337b-4481-b576-7a7244aa877f"],
Cell[24235, 789, 727, 20, 40, "Print",ExpressionUUID->"49cdcf96-5c39-4f7f-ab0d-8778e47cf390"],
Cell[24965, 811, 183, 4, 24, "Print",ExpressionUUID->"f3a8bdb3-213c-4347-87ff-9e15c3754ea5"]
}, Open  ]],
Cell[25163, 818, 364, 10, 76, "Text",ExpressionUUID->"710d2172-b75e-4f02-bd8e-aa87cd85d443"],
Cell[CellGroupData[{
Cell[25552, 832, 126, 1, 30, "Input",ExpressionUUID->"ccba448d-6c91-443c-94cc-42c522113d36"],
Cell[25681, 835, 414, 8, 35, "Output",ExpressionUUID->"479d14d3-1464-4d7e-8456-1dd397dbee44"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26132, 848, 152, 2, 30, "Input",ExpressionUUID->"4c549b27-c282-4bbc-8495-e53f03b7025a"],
Cell[26287, 852, 413, 8, 35, "Output",ExpressionUUID->"7f6adad4-3c3d-4044-bba1-f69808e81752"]
}, Open  ]],
Cell[26715, 863, 180, 3, 53, "Text",ExpressionUUID->"1e9a84a8-55da-4a7a-ae62-dbe7a5b67297"],
Cell[CellGroupData[{
Cell[26920, 870, 143, 2, 30, "Input",ExpressionUUID->"11ff5ff5-828d-4a60-8f2a-279fb77096cf"],
Cell[27066, 874, 169, 2, 34, "Output",ExpressionUUID->"84f078e9-d771-47a5-8c25-f5fd6c3c0371"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27272, 881, 138, 2, 30, "Input",ExpressionUUID->"5bd21521-0d3b-44fa-8392-cc38b4d4456d"],
Cell[27413, 885, 166, 2, 34, "Output",ExpressionUUID->"326ebcd8-98c0-4a85-973e-191442fd80b9"]
}, Open  ]],
Cell[27594, 890, 363, 10, 76, "Text",ExpressionUUID->"4144d348-7f5a-42a9-90f5-b2fb4a4b38ee"],
Cell[CellGroupData[{
Cell[27982, 904, 152, 2, 30, "Input",ExpressionUUID->"7be96441-07da-46ae-8c48-d1b95c822372"],
Cell[28137, 908, 484, 10, 35, "Output",ExpressionUUID->"50d7e277-2ef9-4120-a791-95c7c6ac2f02"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28658, 923, 152, 2, 30, "Input",ExpressionUUID->"915be487-a204-4026-beea-cf2795772640"],
Cell[28813, 927, 484, 10, 35, "Output",ExpressionUUID->"02c01e5d-1e8f-419b-921a-0d0b6c71c825"]
}, Open  ]],
Cell[29312, 940, 180, 3, 53, "Text",ExpressionUUID->"fd03c01e-928d-4843-aa00-23d5b178a19e"],
Cell[CellGroupData[{
Cell[29517, 947, 139, 2, 30, "Input",ExpressionUUID->"a35aed60-87fc-4c3a-a3df-fa3cbbe54ffd"],
Cell[29659, 951, 167, 2, 34, "Output",ExpressionUUID->"a156b4d9-9876-4f60-996b-259e110d00b5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29863, 958, 142, 2, 30, "Input",ExpressionUUID->"bfb5f243-9d30-4205-ae02-20b7bf1c1a1d"],
Cell[30008, 962, 167, 2, 34, "Output",ExpressionUUID->"7805fd59-02e5-4d02-ba7a-de6250b11bc7"]
}, Open  ]],
Cell[30190, 967, 240, 6, 53, "Text",ExpressionUUID->"30238e04-ba0e-4c82-9b9f-17345e4ea5be"],
Cell[CellGroupData[{
Cell[30455, 977, 236, 5, 48, "Input",ExpressionUUID->"01efd926-c74f-4fa0-b413-1b51f76b30dd"],
Cell[30694, 984, 37252, 629, 238, "Output",ExpressionUUID->"22e93b82-c551-41d7-8a74-f1982c99ee59"]
}, Open  ]],
Cell[67961, 1616, 204, 5, 53, "Text",ExpressionUUID->"1bbe19d2-36b5-4d98-9fd6-024baa06792f"],
Cell[CellGroupData[{
Cell[68190, 1625, 248, 5, 48, "Input",ExpressionUUID->"e5a348e6-9515-49d3-bd58-6244fbb25727"],
Cell[68441, 1632, 44076, 741, 262, "Output",ExpressionUUID->"c9fbb740-7b69-4a7a-86d6-f5d935b42d4b"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

